@@ -257,7 +257,7 @@ panel_plugin_external_46_set_properties (PanelPluginExternal *external,
   GSList                *li;
   XEvent                 event;
   PluginProperty        *property;
-  GdkColor               color = { 0, };
+  GdkRGBA                color;
   GdkWindow             *window;
 
   panel_return_if_fail (PANEL_IS_PLUGIN_EXTERNAL_46 (external));
@@ -273,7 +273,8 @@ panel_plugin_external_46_set_properties (PanelPluginExternal *external,
   event.xclient.message_type = panel_atom;
   event.xclient.format = 16;
 
-  gdk_error_trap_push ();
+  window = gtk_socket_get_plug_window (GTK_SOCKET (external));
+  gdk_x11_display_error_trap_push (gdk_window_get_display (window));
 
   for (li = properties; li != NULL; li = li->next)
     {
@@ -296,7 +297,7 @@ panel_plugin_external_46_set_properties (PanelPluginExternal *external,
           break;
 
         case PROVIDER_PROP_TYPE_SET_BACKGROUND_COLOR:
-          if (gdk_color_parse (g_value_get_string (&property->value), &color))
+          if (gdk_rgba_parse (&color, g_value_get_string (&property->value)))
             {
               event.xclient.data.s[1] = color.red;
               event.xclient.data.s[2] = color.green;
@@ -342,9 +343,9 @@ panel_plugin_external_46_set_properties (PanelPluginExternal *external,
 
   bailout:
 
-  gdk_flush ();
+  gdk_display_flush (gdk_window_get_display (window));
 
-  if (gdk_error_trap_pop () != 0)
+  if (gdk_x11_display_error_trap_pop (gdk_window_get_display (window)) != 0)
     {
       g_critical ("Failed to send client messages for %s-%d",
                   panel_module_get_name (external->module),
