@@ -27,6 +27,7 @@ typedef struct _XfceTasklistClass     XfceTasklistClass;
 typedef struct _XfceTasklist          XfceTasklist;
 typedef enum   _XfceTasklistGrouping  XfceTasklistGrouping;
 typedef enum   _XfceTasklistSortOrder XfceTasklistSortOrder;
+typedef enum   _XfceTasklistMClick    XfceTasklistMClick;
 
 #define XFCE_TYPE_TASKLIST            (xfce_tasklist_get_type ())
 #define XFCE_TASKLIST(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), XFCE_TYPE_TASKLIST, XfceTasklist))
@@ -61,16 +62,30 @@ enum _XfceTasklistSortOrder
   XFCE_TASKLIST_SORT_ORDER_DEFAULT = XFCE_TASKLIST_SORT_ORDER_GROUP_TIMESTAMP
 };
 
+enum _XfceTasklistMClick
+{
+  XFCE_TASKLIST_MIDDLE_CLICK_NOTHING, /* do nothing */
+  XFCE_TASKLIST_MIDDLE_CLICK_CLOSE_WINDOW, /* close the window */
+  XFCE_TASKLIST_MIDDLE_CLICK_MINIMIZE_WINDOW, /* minimize, never minimize with button 1 */
+
+  XFCE_TASKLIST_MIDDLE_CLICK_MIN = XFCE_TASKLIST_MIDDLE_CLICK_NOTHING,
+  XFCE_TASKLIST_MIDDLE_CLICK_MAX = XFCE_TASKLIST_MIDDLE_CLICK_MINIMIZE_WINDOW,
+  XFCE_TASKLIST_MIDDLE_CLICK_DEFAULT = XFCE_TASKLIST_MIDDLE_CLICK_NOTHING
+};
+
 
 
 GType xfce_tasklist_get_type                (void) G_GNUC_CONST;
 
-void  xfce_tasklist_set_orientation         (XfceTasklist   *tasklist,
-                                             GtkOrientation  orientation);
+void  xfce_tasklist_set_mode                (XfceTasklist        *tasklist,
+                                             XfcePanelPluginMode  mode);
 
 void  xfce_tasklist_set_size                (XfceTasklist   *tasklist,
                                              gint            size);
 
+void  xfce_tasklist_set_nrows               (XfceTasklist   *tasklist,
+                                             gint            nrows);
+
 void  xfce_tasklist_update_monitor_geometry (XfceTasklist   *tasklist);
 
 G_END_DECLS
